## Description

## Objective

### Technical requirements

### Implementation steps

### Pipeline / Data Analytics

- Deliverable:
- Version:
- Inputs:
- Outputs:
- Architecture:
- Process description:
- URL:
- Platform:

### Data Support

- Geographical area:
- Dataset:
- Current behaviour:
- Expected behaviour:
- Platform:

## Acceptance criteria

## Dependencies

_If there are any dependencies, please mention them here and add links to related stories/epics_
